@@ -30,6 +30,12 @@
 #include <stdarg.h>
 #include <glib/gtypes.h>
 
+/* Suppress warnings when GCC is in -pedantic mode and not -std=c99
+ */
+#if (__GNUC__ >= 3 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 96))
+#pragma GCC system_header
+#endif
+
 G_BEGIN_DECLS
 
 /* calculate a string size, guarranteed to fit format + args.
@@ -187,7 +193,7 @@ GPrintFunc      g_set_printerr_handler  (GPrintFunc      func);
 #ifdef __GNUC__
 
 #define g_assert(expr)			G_STMT_START{		\
-     if (!(expr))						\
+     if (expr) { } else						\
        g_log (G_LOG_DOMAIN,					\
 	      G_LOG_LEVEL_ERROR,				\
 	      "file %s: line %d (%s): assertion failed: (%s)",	\
@@ -207,7 +213,7 @@ GPrintFunc      g_set_printerr_handler  (GPrintFunc      func);
 #else /* !__GNUC__ */
 
 #define g_assert(expr)			G_STMT_START{		\
-     if (!(expr))						\
+     if (expr) { } else						\
        g_log (G_LOG_DOMAIN,					\
 	      G_LOG_LEVEL_ERROR,				\
 	      "file %s: line %d: assertion failed: (%s)",	\
@@ -239,7 +245,7 @@ GPrintFunc      g_set_printerr_handler  (GPrintFunc      func);
 #ifdef __GNUC__
 
 #define g_return_if_fail(expr)		G_STMT_START{			\
-     if (!(expr))							\
+     if (expr) { } else							\
        {								\
 	 g_log (G_LOG_DOMAIN,						\
 		G_LOG_LEVEL_CRITICAL,					\
@@ -252,7 +258,7 @@ GPrintFunc      g_set_printerr_handler  (GPrintFunc      func);
        };				}G_STMT_END
 
 #define g_return_val_if_fail(expr,val)	G_STMT_START{			\
-     if (!(expr))							\
+     if (expr) { } else							\
        {								\
 	 g_log (G_LOG_DOMAIN,						\
 		G_LOG_LEVEL_CRITICAL,					\
@@ -285,7 +291,7 @@ GPrintFunc      g_set_printerr_handler  (GPrintFunc      func);
 #else /* !__GNUC__ */
 
 #define g_return_if_fail(expr)		G_STMT_START{		\
-     if (!(expr))						\
+     if (expr) { } else						\
        {							\
 	 g_log (G_LOG_DOMAIN,					\
 		G_LOG_LEVEL_CRITICAL,				\
@@ -297,7 +303,7 @@ GPrintFunc      g_set_printerr_handler  (GPrintFunc      func);
        };				}G_STMT_END
 
 #define g_return_val_if_fail(expr, val)	G_STMT_START{		\
-     if (!(expr))						\
+     if (expr) { } else						\
        {							\
 	 g_log (G_LOG_DOMAIN,					\
 		G_LOG_LEVEL_CRITICAL,				\
