@@ -58,26 +58,34 @@
  * RTLD_GLOBAL - the external symbols defined in the library will be made
  *		 available to subsequently loaded libraries.
  */
-#ifndef	RTLD_GLOBAL
-#define	RTLD_GLOBAL	0
-#endif	/* RTLD_GLOBAL */
 #ifndef	RTLD_LAZY
 #define	RTLD_LAZY	1
 #endif	/* RTLD_LAZY */
 #ifndef	RTLD_NOW
 #define	RTLD_NOW	0
 #endif	/* RTLD_NOW */
+/* some systems (OSF1 V5.0) have broken RTLD_GLOBAL linkage */
+#ifdef G_MODULE_BROKEN_RTLD_GLOBAL
+#undef	RTLD_GLOBAL
+#endif /* G_MODULE_BROKEN_RTLD_GLOBAL */
+#ifndef	RTLD_GLOBAL
+#define	RTLD_GLOBAL	0
+#endif	/* RTLD_GLOBAL */
 
 
 /* --- functions --- */
 static gchar*
-fetch_dlerror (void)
+fetch_dlerror (gboolean replace_null)
 {
   gchar *msg = dlerror ();
 
-  /* make sure we always return an error message != NULL */
+  /* make sure we always return an error message != NULL, if
+   * expected to do so. */
 
-  return msg ? msg : "unknown dl-error";
+  if (!msg && replace_null)
+    return "unknown dl-error";
+
+  return msg;
 }
 
 static gpointer
@@ -88,7 +96,7 @@ _g_module_open (const gchar *file_name,
   
   handle = dlopen (file_name, RTLD_GLOBAL | (bind_lazy ? RTLD_LAZY : RTLD_NOW));
   if (!handle)
-    g_module_set_error (fetch_dlerror ());
+    g_module_set_error (fetch_dlerror (TRUE));
   
   return handle;
 }
@@ -104,7 +112,7 @@ _g_module_self (void)
   
   handle = dlopen (NULL, RTLD_GLOBAL | RTLD_LAZY);
   if (!handle)
-    g_module_set_error (fetch_dlerror ());
+    g_module_set_error (fetch_dlerror (TRUE));
   
   return handle;
 }
@@ -121,7 +129,7 @@ _g_module_close (gpointer handle,
   if (is_unref)
     {
       if (dlclose (handle) != 0)
-	g_module_set_error (fetch_dlerror ());
+	g_module_set_error (fetch_dlerror (TRUE));
     }
 }
 
@@ -133,7 +141,7 @@ _g_module_symbol (gpointer     handle,
   
   p = dlsym (handle, symbol_name);
   if (!p)
-    g_module_set_error (fetch_dlerror ());
+    g_module_set_error (fetch_dlerror (FALSE));
   
   return p;
 }
